import { dirname, join } from "node:path";
import { fileURLToPath } from "node:url";
import { glob } from "glob";
import type { FastifyInstance, RouteOptions } from "fastify";

import log from "./log.js";

export default async function getRoutes() {
	const rootDir = dirname(fileURLToPath(import.meta.url));

	const routes: RouteOptions[] = [];
	const matches = await glob(join(rootDir, "/routes/**/*.{js,ts}"));

	for (const filename of matches) {
		try {
			const mod = await import(filename);
			routes.push(mod.default as RouteOptions);
		} catch (e) {
			log.error("Importing route %s", filename, e);
		}
	}

	return routes;
}

export function mountRoutes(app: FastifyInstance, routes: RouteOptions[]) {
	for (const route of routes) {
		log.trace("Mounting route %s %s", route.method, route.url);
		app.route(route);
	}
}
