import type { RouteOptions } from "fastify";

import log from "~/log.js";
import LongmontDataSource from "~/db/index.js";
import { Account } from "~entities/account.js";
import { BASE_URL } from "~/config.js";

const route: RouteOptions = {
	method: "GET",
	url: "/.well-known/longmont/auth-lookup",
	handler: async (req, res) => {
		// TypeScript complains if we just use plain `req.query` :(
		const encodedResource = (req.query as { acct: string }).acct;

		if (!encodedResource || typeof encodedResource !== "string") {
			res.status(400).send({
				error: "resource query parameter is missing or invalid",
			});
			return;
		}
		const resource = decodeURIComponent(encodedResource);

		log.debug("Handling auth lookup request for %s", resource);

		const account = await LongmontDataSource.getRepository(Account).findOneBy({
			username: resource,
		});
		if (!account) {
			res.status(404).send({
				error: "Account not found",
			});
			return;
		}

		res.send({
			subject: account.username,
			href: `${BASE_URL}/users/${account.id}`,
		});
	},
};

export default route;
