import "reflect-metadata"; // Required for TypeORM
import Fastify from "fastify";

import LongmontDataSource from "./db/index.js";
import log from "./log.js";
import { PORT } from "./config.js";
import getRoutes, { mountRoutes } from "./routes.js";

export default async function start() {
	log.info("Initializing database");
	await LongmontDataSource.initialize();

	const pendingMigrations = await LongmontDataSource.showMigrations();
	if (pendingMigrations) {
		log.error(
			"There are pending migrations, please run these with `pnpm migrate`.",
		);
		return;
	}

	log.debug("Setting up routes");
	const app = Fastify();

	app.setNotFoundHandler((req, res) => {
		log.debug("Route %s not found", req.url);
		res.status(404).send({ message: "Not found" });
	});

	const routes = await getRoutes();
	mountRoutes(app, routes);

	log.info("Listening on port %d", PORT);
	await app.listen({ port: PORT });
}
